<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\User;
use App\Branches;
use App\Company;
use App\Payment;
use App\Client;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Auth;
use Carbon\Carbon;
class SuperadminController extends Controller
{
    // public function index()
    // {
    //     $data['clients'] = User::all();
    //     $data['totalClients'] = User::count();

    //     // Debugging line to check the content of $data
    //     // dd($data);

    //     return view('super_admin.index', compact('data',));
    // }

    public function index()
    {
        // Calculate the revenue for the current month
        $currentMonthRevenue = Branches::whereMonth('created_at', now()->month)
            ->whereYear('created_at', now()->year)
            ->sum('price');

        // Calculate the revenue for the previous month
        $previousMonthRevenue = Branches::whereMonth('created_at', now()->subMonth()->month)
            ->whereYear('created_at', now()->subMonth()->year)
            ->sum('price');

        // Calculate the percentage change in revenue
        $percentageChangeRevenue = ($currentMonthRevenue - $previousMonthRevenue) / ($previousMonthRevenue ?: 1) * 100;

        // Calculate the count of upcoming expiries for the current month
        $upcomingExpiryCount = Branches::whereMonth('expiry_date', now()->month)
            ->whereYear('expiry_date', now()->year)
            ->where('expiry_date', '>', now())
            ->count();

        // Your other calculations for clients and expired branches
        $previousMonthClients = User::whereMonth('created_at', now()->subMonth()->month)->count();
        $currentMonthClients = User::whereMonth('created_at', now()->month)->count();
        $previousMonthExpiredCount = Branches::whereMonth('expiry_date', now()->subMonth()->month)
            ->whereYear('expiry_date', now()->subMonth()->year)
            ->count();
        $currentMonthExpiredCount = Branches::whereMonth('expiry_date', now()->month)
            ->whereYear('expiry_date', now()->year)
            ->count();
        $percentageChangeClients = ($currentMonthClients - $previousMonthClients) / ($previousMonthClients ?: 1) * 100;
        $percentageChangeExpired = ($currentMonthExpiredCount - $previousMonthExpiredCount) / ($previousMonthExpiredCount ?: 1) * 100;

        $sixMonthsAgo = Carbon::now()->subMonths(5);

        $adminsLastSixMonths = User::selectRaw('YEAR(created_at) as year, MONTH(created_at) as month, CONCAT(MONTHNAME(created_at), " ", YEAR(created_at)) as month_year, COUNT(*) as total')
        ->where('role', 'Admin')
        ->where('created_at', '>=', $sixMonthsAgo)
        ->groupBy('month_year')
        ->get();

        $categoriesAdminsLastSixMonths = $adminsLastSixMonths->pluck('month_year')->toArray();
        $seriesDataPurchaseAdminsLastSixMonths = $adminsLastSixMonths->pluck('total')->toArray();



        // dd($categoriesAdminsLastSixMonths,$seriesDataPurchaseAdminsLastSixMonths);


        return view('super_admin.index', compact('currentMonthRevenue', 'percentageChangeRevenue', 'currentMonthClients', 'percentageChangeClients', 'currentMonthExpiredCount', 'percentageChangeExpired', 'upcomingExpiryCount','categoriesAdminsLastSixMonths','seriesDataPurchaseAdminsLastSixMonths'));
    }

    public function changepass() {
        return view('super_admin.superadmin-changepass');
    }

    public function update(Request $request)
{
    $request->validate([
        'old_password' => 'required',
        'password' => 'required|string|min:8|confirmed',
    ]);

    $user = Auth::user();

    if (!Hash::check($request->old_password, $user->password)) {
        return redirect()->route('change.password')->with('error', 'The old password is incorrect.');
    }

    $user->password = Hash::make($request->password);
    $user->save();

    return redirect()->back()->with('success', 'Password changed successfully.');
}


    // public function marketing() {
    //     return view('super_admin.superadmin-marketing');
    // }
    public function showPayments()
    {
        $payments = Payment::orderByDesc('id')->get();

        return view('super_admin.payment.index', compact('payments'));
    }



    public function payments(Request $request)
    {
        $data['companyName']  = $request->input('companyName');
        $data['branchName']  = $request->input('branchName');
        $data['branchCurrency']  = $request->input('branchCurrency');
        $data['branchPrice']  = $request->input('branchPrice');

        $data['clients'] = User::orderBy('created_at', 'desc')->get();
        $data['branches'] = Branches::orderBy('created_at', 'desc')->get();
        $data['companies'] = Company::orderBy('created_at', 'desc')->get();

        return view('super_admin.payment.add', $data);
    }

    public function insert(Request $request)
    {
        $request->validate([
            'user_name' => 'required|string',
            'company_name' => 'required|string',
            'branch_name' => 'required|string',
            'date' => 'required|date',
            'amount' => 'required|numeric',
            'note' => 'nullable|string',
        ]);

        $payment = new Payment();
        $payment->user_name = $request->user_name;
        $payment->company_name = $request->company_name;
        $payment->branch_name = $request->branch_name;
        $payment->date = $request->date;
        $payment->amount = $request->amount;
        $payment->note = $request->note;

        $payment->save();

        return redirect()->route('show.payments')->with('success', 'Payment added successfully');
    }
    public function edit($id)
{
    $payment = Payment::findOrFail($id);
    $clients = User::all();
    $companies = Company::all();
    $branches = Branches::all();

    return view('super_admin.payment.edit', compact('payment', 'clients', 'companies', 'branches'));
}

    public function updatepayment(Request $request, $id)
{
    $request->validate([
    ]);

    $payment = Payment::findOrFail($id);

    $payment->update([
        'user_name' => $request->input('user_name'),
        'company_name' => $request->input('company_name'),
        'branch_name' => $request->input('branch_name'),
        'date' => $request->input('date'),
        'amount' => $request->input('amount'),
        'note' => $request->input('note'),
    ]);

    return redirect()->route('show.payments')->with('success', 'Payment updated successfully');
}


}

