<?php

namespace App\Http\Controllers;

use App\AdminOtherAccount;
use App\AdminPeriodClosing;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Http\Request;

class AdminPeriodClosingController extends Controller
{
    use SoftDeletes;

    public function index()
    {
        $periodClosings = AdminPeriodClosing::where('branch_id', session()->get('selected_branch'))->orderBy('id', 'desc')->get();
        return view('crusher.periodclosing_master.index', compact('periodClosings'));
    }

    public function create()
    {
        return view('crusher.periodclosing_master.create');
    }

    function store(Request $request)
    {
        try {
            $validatedData = $request->validate([
                'from' => 'nullable|date',
                'to' => 'nullable|date',
                'carry_opening_balance' => 'nullable|boolean',
            ]);
            $validatedData['branch_id'] = session()->get('selected_branch');
            AdminPeriodClosing::create($validatedData);

            flash()->addSuccess('Record Created');
            return redirect()->route('crusher.period_closings.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function edit($periodClosing)
    {
        $periodClosing = AdminPeriodClosing::find($periodClosing);
        return view('crusher.periodclosing_master.edit', compact('periodClosing'));
    }

    function update(Request $request, $periodClosing)
    {
        try {
            $validatedData = $request->validate([
                'from' => 'nullable|date',
                'to' => 'nullable|date',
                'carry_opening_balance' => 'nullable|boolean',
            ]);
            $validatedData['branch_id'] = session()->get('selected_branch');

            AdminPeriodClosing::find($periodClosing)->update($validatedData);

            flash()->addSuccess('Record Updated');
            return redirect()->route('crusher.period_closings.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show($periodClosing)
    {
        $periodClosing = AdminPeriodClosing::find($periodClosing);
        return view('crusher.periodclosing_master.view', compact('periodClosing'));
    }

    public function softDelete($periodClosing)
    {
        $periodClosing = AdminPeriodClosing::findOrFail($periodClosing);
        $periodClosing->delete();
        flash()->addSuccess('Success');
        return redirect()->route('crusher.period_closings.index');
    }
}
