<?php

namespace App\Http\Controllers;
use App\Http\Requests\StoreItemGroupRequest;
use App\Http\Requests\UpdateItemGroupRequest;
use App\ItemsGroup;
use Illuminate\Http\Request;
use Illuminate\Database\Eloquent\SoftDeletes;


class ItemgroupMasterController extends Controller
{

    use SoftDeletes;

    public function index()
    {
        $itemGroups = ItemsGroup::where('branch_id', session()->get('selected_branch'))->orderBy('id', 'desc')->get();
        return view('crusher.itemgroup_master.index', compact('itemGroups'));
    }


public function create()
    {
        return view('crusher.itemgroup_master.create');
    }

    function store(StoreItemGroupRequest $request)
    {
        try {
            $validatedData = $request->validated();

            foreach ($validatedData['groups'] as $key => $group) {
                ItemsGroup::create(['branch_id'=>session()->get('selected_branch'), 'group'=>$group]);
            }


            flash()->addSuccess('Record Created');
            return redirect()->route('crusher.item_group.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function edit($itemGroup)
    {
        $itemGroup = ItemsGroup::find($itemGroup);
        return view('crusher.itemgroup_master.edit', compact('itemGroup'));
    }

    function update(UpdateItemGroupRequest $request, $itemGroup)
    {
        try {
            $validatedData = $request->validated();

            $itemGroup = ItemsGroup::find($itemGroup)->update($validatedData);

            flash()->addSuccess('Record Updated');
            return redirect()->route('crusher.item_group.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }


    public function view()
    {
        return view('crusher.itemgroup_master.view');
    }

    public function softDelete($itemGroup)
    {
        $itemGroup = ItemsGroup::findOrFail($itemGroup);
        $itemGroup->delete();
        flash()->addSuccess('Success');
        return redirect()->route('crusher.item_group.index');
    }
}
