<?php

namespace App\Http\Controllers;

use App\AdminOtherAccount;
use App\AdminPaymentVoucher;
use App\AdminSalesInvoice;
use App\Company;
use App\Customer;
use App\Expense;
use App\PaymentVoucherExpense;
use App\StaffAndSalesman;
use App\Supplier;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Permission;
use App\Branches;

class adminPaymentVoucherController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        $vouchers = AdminPaymentVoucher::with('expense.account')
        ->whereIn('id', function ($query) {
            $query->selectRaw('MIN(id)')
                ->from('admin_payment_vouchers')
                ->where('branch_id', session()->get('selected_branch'))
                    ->whereNotNull('invoice_no')
                    ->groupBy('invoice_no');
        })
        ->withTrashed()
        ->orderBy('invoice_no', 'desc')->get();


        return view('crusher.trans_payment_voucher.index', compact('vouchers'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
         // Retrieve permission titles from Permission table
         $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

         // Filter permission titles using hasBranchPermission function
         $filteredPermissionTitles = [];
         $branchId = session()->get('selected_branch');
         foreach ($permissionTitles as $permissionTitle) {
             if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
                 $filteredPermissionTitles[] = $permissionTitle;
             }
         }

        $salesInvoices = AdminSalesInvoice::where('branch_id', session()->get('selected_branch'))->groupBy('invoice_no')->get();
        // dd($salesInvoices);
        $currentDate = Carbon::now()->format('Ymd');
        $expenses = Expense::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });
        $otherAccountExpenses = AdminOtherAccount::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        $expensesAccount = $expenses->concat($otherAccountExpenses);

        // Get the latest quotation number for the branch
        $latestVoucher = AdminPaymentVoucher::withTrashed()->where('branch_id', session()->get('selected_branch'))
            ->latest('invoice_no')->first();

        // Calculate the new quotation number
        if ($latestVoucher) {
            $lastVoucher = (int)substr($latestVoucher->invoice_no, -4); // Extract the last 4 digits
            $newNumber = $lastVoucher + 1;
            $newVoucher = str_pad($newNumber, 4, '0', STR_PAD_LEFT);
        } else {
            $newVoucher = '0001';
        }



        // // Retrieve customers and include both 'account_name' and 'table_name' attributes
        // $customers = Customer::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Customer');
        // });

        // // Retrieve suppliers and include both 'account_name' and 'table_name' attributes
        // $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Supplier');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        // ->whereIn(DB::raw("CONCAT(first_name, ' ', last_name)"), $filteredPermissionTitles)
        // ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Expense');
        // });

        // // Retrieve other accounts and set 'table_name' to the fully-qualified model class name
        // $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        // });

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Customer');
        });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Supplier');
        });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("CONCAT(REPLACE(first_name, ' ', '-'), '-', REPLACE(last_name, ' ', '-'))"), $filteredPermissionTitles)
        ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) AS account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });


        $expense = Expense::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $customer = Customer::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $Supplier = Supplier::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $AdminOtherAccount = AdminOtherAccount::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $staffAndSalesman = StaffAndSalesman::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1])
            ->select('*', DB::raw("CONCAT(first_name) as account_name"))
            ->get();

        // Concatenate all Bank accounts collections into a single collection
        $Bankaccounts = $expense->get()->merge($customer->get())->merge($Supplier->get())->merge($AdminOtherAccount->get())->merge($staffAndSalesman);

        // Concatenate all accounts collections into a single collection
        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);

        return view('crusher.trans_payment_voucher.create', compact('newVoucher', 'customers', 'accounts', 'salesInvoices', 'expensesAccount','Bankaccounts'));
    }


    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // dd($request);
        $latestNo = AdminPaymentVoucher::withTrashed()->where('branch_id', session()->get('selected_branch'))
        ->latest('invoice_no')->first();

        if ($latestNo) {
        $latestInvoiceNo = $latestNo->invoice_no;

        $latestNumber = (int)preg_replace('/[^0-9]/', '', $latestInvoiceNo);

        $newNumber = $latestNumber + 1;

        $newInvoiceNo = str_pad($newNumber, 4, '0', STR_PAD_LEFT);
        } else {
        $newInvoiceNo = '0001';
        }
        try {
            $validatedData = $request->validate([
                'date' => 'nullable|date',
                // 'invoice_no' => 'nullable|string',
                'payment_method' => 'required|in:cash,bank',
                'bank_id' => 'nullable|nullable:payment_method,bank',
                'bank_name' => 'nullable',
                'cheaque_no' => 'nullable|nullable:payment_method,bank|string',
                'cheaque_date' => 'nullable|nullable:payment_method,bank|date',
                // 'bank_name' => 'nullable|required_if:payment_method,bank|string',
                // 'account_id' => 'nullable|array',
                'narration' => 'nullable',
                'account_id' => 'nullable',
                // 'account_type' => 'nullable|array',
                'account_type' => 'nullable',
                'amount' => 'nullable|array',
                'amount.*' => 'nullable|numeric',
                'AmountInWords' => 'nullable|string',
                'bill_wise_id' => 'nullable|array',
                'bill_wise_id.*' => 'nullable',
                'inovice_id' => 'nullable|array',
                'inovice_id.*' => 'nullable',
                'expense_type' => 'nullable|array',
                'expense_type.*' => 'nullable',
                // 'account_name' => 'nullable|array',
                'account_name' => 'nullable',
                'expense_id' => 'nullable|array',
                'expense_id.*' => 'nullable',
                'expense_amount' => 'nullable|array',
                'expense_amount.*' => 'nullable|numeric',
                'new_vat_amount' => 'nullable|string',
            ]);
            $branch_id = session()->get('selected_branch');

            $data = [
                'invoice_no' => $newInvoiceNo,
                'date' => $validatedData['date']??(NULL),
                'payment_method' => $validatedData['payment_method']??(NULL),
                'bank_id' => $validatedData['bank_id']??(NULL),
                'bank_name' => $validatedData['bank_name']??(NULL),
                'cheaque_no' => $validatedData['cheaque_no']??(NULL),
                'cheaque_date' => $validatedData['cheaque_date']??(NULL),
                'account_name' => $validatedData['account_name']??(NULL),
                'branch_id' => $branch_id,
                'narration' => $validatedData['narration']??(NULL),
                'new_vat_amount' => $validatedData['new_vat_amount']??(NULL),
            ];

                $paymentVoucher = AdminPaymentVoucher::create($data);
            for ($j = 0; $j < count($validatedData['bill_wise_id']); $j++) {
                PaymentVoucherExpense::create([
                    'invoice_no' => $newInvoiceNo,
                    'voucher_id' => $paymentVoucher->id,
                    'branch_id' => $branch_id,
                    'date' => $validatedData['date']??'',
                    'account_id' => $validatedData['account_id']??'',
                    'account_type' => $validatedData['account_type']??'',
                    'payment_method' => $validatedData['payment_method'][$j]??(NULL),
                    'amount' => $validatedData['amount'][$j]??(NULL),
                    'AmountInWords' => $validatedData['AmountInWords'][$j]??(NULL),
                    'bill_wise_id' => $validatedData['bill_wise_id'][$j]??(NULL),
                    'inovice_id' => $validatedData['bill_wise_id'][$j]=='BillWise'?$validatedData['inovice_id'][$j]:(NULL),
                    'expense_type' => $validatedData['expense_type'][$j]??(NULL),
                    'account_name' => $validatedData['account_name']??'',
                    'bank_name' => $validatedData['bank_name']??'',
                    'expense_id' => $validatedData['expense_id'][$j]??(NULL),
                    'expense_amount' => $validatedData['expense_amount'][$j]??(NULL),
                    'new_vat_amount' => $validatedData['new_vat_amount']??(NULL),

                ]);
            }

            flash()->addSuccess('Record Created');
            return redirect()->route('crusher.payment_vouchers.index');
        } catch (\Throwable $th) {
            // dd($th);
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    public function show($paymentVoucher)
    {
        $paymentVoucher = AdminPaymentVoucher::withTrashed()->find($paymentVoucher);
        $paymentVoucher = $paymentVoucher->withTrashed()->with('expense.account', 'expense.expense')->where('invoice_no', $paymentVoucher->invoice_no)->where('branch_id', session()->get('selected_branch'))->get();
        // dd($paymentVoucher);
        $company = Company::where('user_id', auth()->id())->first();
        return view('crusher.trans_payment_voucher.view', compact('paymentVoucher', 'company'));
    }

    public function edit(AdminPaymentVoucher $paymentVoucher)
    {
        // Retrieve permission titles from Permission table
        $permissionTitles = Permission::where('branch_id', session()->get('selected_branch'))->pluck('name')->toArray();

        // Filter permission titles using hasBranchPermission function
        $filteredPermissionTitles = [];
        $branchId = session()->get('selected_branch');
        foreach ($permissionTitles as $permissionTitle) {
            if (Branches::hasBranchPermission($branchId, $permissionTitle)) {
                $filteredPermissionTitles[] = $permissionTitle;
            }
        }

        $expenses = Expense::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });
        $otherAccountExpenses = AdminOtherAccount::where(['branch_id'=>session()->get('selected_branch'), 'class_of_account_id'=>'Tax & Duties'])
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        $expensesAccount = $expenses->concat($otherAccountExpenses);

        // // Retrieve customers and include both 'account_name' and 'table_name' attributes
        // $customers = Customer::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Customer');
        // });

        // // Retrieve suppliers and include both 'account_name' and 'table_name' attributes
        // $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('name_of_organisation', $filteredPermissionTitles)
        // ->select('*', 'name_of_organisation as account_name')
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Supplier');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        // ->whereIn(DB::raw("CONCAT(first_name, ' ', last_name)"), $filteredPermissionTitles)
        // ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) as account_name"))
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        // });

        // // Retrieve expenses and set 'table_name' to the fully-qualified model class name
        // $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\Expense');
        // });

        // // Retrieve other accounts and set 'table_name' to the fully-qualified model class name
        // $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        // ->whereIn('account_name', $filteredPermissionTitles)
        // ->get()
        // ->map(function ($item) {
        //     return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        // });

        $customers = Customer::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Customer');
        });

        $suppliers = Supplier::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(name_of_organisation, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(name_of_organisation) as account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Supplier');
        });

        $salesmens = StaffAndSalesman::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("CONCAT(REPLACE(first_name, ' ', '-'), '-', REPLACE(last_name, ' ', '-'))"), $filteredPermissionTitles)
        ->select('*', DB::raw("CONCAT(first_name, ' ', last_name) AS account_name"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\StaffAndSalesman');
        });

        $expenses = Expense::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\Expense');
        });

        $otherAccounts = AdminOtherAccount::where('branch_id', session()->get('selected_branch'))
        ->whereIn(DB::raw("REPLACE(account_name, ' ', '-')"), $filteredPermissionTitles)
        ->select('*', DB::raw("(account_name)"))
        ->get()
        ->map(function ($item) {
            return $item->setAttribute('table_name', 'App\AdminOtherAccount');
        });

        $expense = Expense::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $customer = Customer::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $Supplier = Supplier::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $AdminOtherAccount = AdminOtherAccount::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1]);
        $staffAndSalesman = StaffAndSalesman::where(['branch_id' => session()->get('selected_branch'), 'class_of_account_id' => 1])
            ->select('*', DB::raw("CONCAT(first_name) as account_name"))
            ->get();

        // Concatenate all Bank accounts collections into a single collection
        $Bankaccounts = $expense->get()->merge($customer->get())->merge($Supplier->get())->merge($AdminOtherAccount->get())->merge($staffAndSalesman);

        // Concatenate all collections into a single collection
        $accounts = $customers->concat($expenses)->concat($suppliers)->concat($otherAccounts)->concat($salesmens);
;
        // $paymentVouchers = $paymentVoucher->with('expense.account')->where('invoice_no', $paymentVoucher->invoice_no)->get();

        $paymentVouchers = AdminPaymentVoucher::where('branch_id', session()->get('selected_branch'))
        ->with('expense.account')
        ->where('invoice_no', $paymentVoucher->invoice_no)
        ->get();

        // dd($paymentVouchers);

        $salesInvoices = AdminSalesInvoice::where('branch_id', session()->get('selected_branch'))->groupBy('invoice_no')->get();

        return view('crusher.trans_payment_voucher.edit', compact('accounts', 'paymentVouchers', 'expensesAccount', 'salesInvoices','Bankaccounts'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\AdminPaymentVoucher  $adminReceiptVoucher
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, AdminPaymentVoucher $paymentVoucher)
    {
        // dd($request);
        try {
            $validatedData = $request->validate([
                'date' => 'nullable|date',
                'invoice_no' => 'nullable|string',
                'payment_method' => 'required|in:cash,bank',
                'bank_id' => 'nullable|required_if:payment_method,bank',
                'bank_name' => 'nullable',
                'cheaque_no' => 'nullable|nullable:payment_method,bank|string',
                'cheaque_date' => 'nullable|nullable:payment_method,bank|date',
                // 'bank_name' => 'nullable|required_if:payment_method,bank|string',
                // 'account_id' => 'nullable|array',
                'account_id' => 'nullable',
                // 'account_type' => 'nullable|array',
                'account_type' => 'nullable',
                'amount' => 'nullable|array',
                'amount.*' => 'nullable|numeric',
                'AmountInWords' => 'nullable|string',
                'bill_wise_id' => 'nullable|array',
                'bill_wise_id.*' => 'nullable',
                'inovice_id' => 'nullable|array',
                'inovice_id.*' => 'nullable',
                'expense_type' => 'nullable|array',
                'expense_type.*' => 'nullable',
                'account_name' => 'nullable|array',
                'account_name' => 'nullable',
                'expense_id' => 'nullable|array',
                'expense_id.*' => 'nullable',
                'expense_amount' => 'nullable|array',
                'expense_amount.*' => 'nullable|numeric',
                'narration' => 'nullable',
                'new_vat_amount' => 'nullable|string',

            ]);

            $branch_id = session()->get('selected_branch');

            $data = [
                'invoice_no' => $validatedData['invoice_no']??(NULL),
                'date' => $validatedData['date']??(NULL),
                'payment_method' => $validatedData['payment_method']??(NULL),
                'bank_id' => $validatedData['bank_id']??(NULL),
                'bank_name' => $validatedData['bank_name']??(NULL),
                'cheaque_no' => $validatedData['cheaque_no']??(NULL),
                'cheaque_date' => $validatedData['cheaque_date']??(NULL),
                'account_name' => $validatedData['account_name']??(NULL),
                'narration' => $validatedData['narration']??(NULL),
                'branch_id' => $branch_id,
                'new_vat_amount' => $validatedData['new_vat_amount']??(NULL),

            ];
            $paymentVoucher->with('expense.account')->where('invoice_no', $paymentVoucher->invoice_no)->forceDelete();


            $paymentVoucher = AdminPaymentVoucher::create($data);
            PaymentVoucherExpense::where('voucher_id', $paymentVoucher->id)->forceDelete();
            for ($j = 0; $j < count($validatedData['bill_wise_id']); $j++) {
                PaymentVoucherExpense::create([
                    'voucher_id' => $paymentVoucher->id,
                    'branch_id' => $branch_id,
                    'date' => $validatedData['date']??'',
                    'invoice_no' => $validatedData['invoice_no']??'',
                    'account_id' => $validatedData['account_id']??(NULL),
                    'account_type' => $validatedData['account_type']??(NULL),
                    'amount' => $validatedData['amount'][$j]??(NULL),
                    'payment_method' => $validatedData['payment_method'][$j]??(NULL),
                    'AmountInWords' => $validatedData['AmountInWords'][$j]??(NULL),
                    'bill_wise_id' => $validatedData['bill_wise_id'][$j]??(NULL),
                    'inovice_id' => $validatedData['bill_wise_id'][$j]=='BillWise'?$validatedData['inovice_id'][$j]:(NULL),
                    'expense_type' => $validatedData['expense_type'][$j]??(NULL),
                    'account_name' => $validatedData['account_name']??(NULL),
                    'bank_name' => $validatedData['bank_name']??(NULL),
                    'expense_id' => $validatedData['expense_id'][$j]??(NULL),
                    'expense_amount' => $validatedData['expense_amount'][$j]??(NULL),
                    'new_vat_amount' => $validatedData['new_vat_amount']??(NULL),

                ]);
            }

            flash()->addSuccess('Record Updated');
            return redirect()->route('crusher.payment_vouchers.index');
        } catch (\Throwable $th) {
            flash()->addError($th->getMessage());
            return redirect()->back()->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\AdminPaymentVoucher  $adminReceiptVoucher
     * @return \Illuminate\Http\Response
     */
    public function destroy(AdminPaymentVoucher $adminReceiptVoucher)
    {
        //
    }

    public function softDelete($paymentVoucher)
    {
        $paymentVoucher = AdminPaymentVoucher::findOrFail($paymentVoucher);
        $paymentVoucher->where('branch_id', session()->get('selected_branch'))->where('invoice_no', $paymentVoucher->invoice_no)->delete();
        flash()->addSuccess('Success');
        return redirect()->route('crusher.payment_vouchers.index');
    }
}
